@@ -3,6 +3,7 @@ import sys
 import argparse
 import subprocess
 import openai
+import pyperclip
 import os
 from urllib.parse import quote
 from simple_term_menu import TerminalMenu
@@ -67,7 +68,7 @@ The command the user is looking for is:
     # Call openai api to get the command completion
     openai.api_key = os.environ.get("OPENAI_API_KEY")
     if openai.api_key is None:
-        print("To use copilo please set the OPENAI_API_KEY environment variable")
+        print("To use copilot please set the OPENAI_API_KEY environment variable")
         print("You can get an API key from https://beta.openai.com/account/api-keys")
         print("To set the environment variable, run:")
         print("export OPENAI_API_KEY=<your key>")
@@ -92,8 +93,8 @@ The command the user is looking for is:
         os.system(cmd)
     elif menu_entry_index == 1:
         print("> copied")
-        subprocess.run(["pbcopy"], input=cmd, encoding="utf-8")
+        pyperclip.copy(cmd)
     elif menu_entry_index == 2:
         link = "https://explainshell.com/explain?cmd=" + quote(cmd)
         print("> explainshell: " + link)
-        subprocess.run(["open", "https://explainshell.com/explain?cmd=" + quote(cmd)])
\ No newline at end of file
+        subprocess.run(["open", "https://explainshell.com/explain?cmd=" + quote(cmd)])
